/* -------------------  TXTOOLS.C  -------------------

     Einige wenige Funktionen fuer die Bildschirm-
     steuerung im Textmodus

     07.02.2015  R. Seelig
   --------------------------------------------------- */


#include "txtools.h"


// ----------------- Globale Variable ---------------

char axofs = 0;
char ayofs = 0;
unsigned char colattr = 0x07;

uint8_t txwherex= 0;
uint8_t txwherey= 0;
struct txfntset txfnt;

// ---------------  Prototypen Text -----------------

/*
void txinit(void);
void settextcolor(unsigned char col);
void setbkcolor(unsigned char col);
void settextattr(unsigned char attr);
void clrscr(void);
void gotoxy(unsigned char x, unsigned char y);
void txbar(char x1, char y1, char x2, char y2, char f);
void settxfont(char nr);
void tx_putchar(int ch, char c1, char c2);
int getch(void);
int keypressed(void);
unsigned int readkey(void);

*/


// ----------------  Daten - ARRAYs  ----------------


//                Textfarbpalette EGA-Farben
//                sw  bl  gn  cy  rt  mg  br  gr

char txpal[]   = {30, 34, 32, 36, 31, 35, 33, 37};
char bkpal[]   = {40, 44, 42, 46, 41, 45, 41, 47};

void txinit(void)
{

}

// -------------------------------------------------------------------------------
//                    I M P L E M E N T I E R U N G E N
// -------------------------------------------------------------------------------

// --------------------------------------------------
//                   SETTEXTCOLOR
//   Setzt die Textvordergrundfarbe mit der
//   in <txpal> angegebenen Textfarbe (EGA -
//   kompatibel)
// --------------------------------------------------
void settextcolor(unsigned char col)
{
  char intensity;
  intensity= (col / 8);
  if (intensity== 0) {intensity= 21;} else {intensity= 1;}
  printf("\033[%d;%dm",intensity,txpal[col%8]);
  colattr &= 0x0f;
  colattr |= col;

}


// --------------------------------------------------
//                   SETBKCOLOR
//   Setzt die Texthintergrundfarbe mit der
//   in <bkpal> angegebenen Textfarbe (EGA -
//   kompatibel)
// --------------------------------------------------
void setbkcolor(unsigned char col)
{
  char intensity;
  intensity= (col / 8);
  if (intensity== 0) {intensity= 25;} else {intensity= 5;}
  printf("\033[%d;%dm",bkpal[col%8],intensity);
  colattr &= 0x0f;
  colattr |= (col << 4);
}

// --------------------------------------------------
//                     CLRSCR
//   loescht den Bildschrim mit der mit <setbkcolor>
//   angegebenen Farbe
// --------------------------------------------------
void clrscr(void)
{
  int i;
  // leider habe ich keinen anderen (schnellen) Weg (bisher) gefunden, um
  // den kompletten Hintergrund einzufaerben, als einfach mehere Zeilen mit
  // den Textattributen auf das Terminal zu schreiben und dann den Cursor
  // in die "Homeposition" zu bringen ...

  for (i= 0; i< 6; i++) { printf(" \n"); }
  printf("\033[2J");
  printf("\033[0;0H");
  gotoxy(1,1);
}

// --------------------------------------------------
//                    SETTEXTATTR
//   setzt die Text UND die Hintergrundfarbe mit der
//   in ATTR angegebenen Farbe. Die hoeherwertigen
//   4 Bits bestimmen die Hintergrundfarbe, die
//   niederen 4 Bits die Vordergrundfarbe.
// --------------------------------------------------

void settextattr(unsigned char attr)
{
  setbkcolor(attr >> 4);
  settextcolor(attr & 0x0f);
  colattr = attr;
}

// --------------------------------------------------
//                      GOTOXY
//   positioniert den Textcursor an die mit x/y
//   angegebene Textkoordinate.
// --------------------------------------------------
void gotoxy(unsigned char x, unsigned char y)
{
  x += axofs;
  y += ayofs;
  txwherex= x;
  txwherey= y;
  printf("\033[%d;%dH",y,x);
}

// --------------------------------------------------
//                      TXBAR
//   erzeugt einen "leeren" Bildschirmbereich,
//   der mit dem Farbattribut <f> ausgefuellt ist.
// --------------------------------------------------
void txbar(char x1, char y1, char x2, char y2, char f)
{
  int x,y;

  settextattr(f);
  for (y= y1; y< y2+1; y++)
  {
        gotoxy(x1,y);
        for (x= x1; x< x2+1; x++)
        {
          putchar(' ');
        }
  }
}

void settxfont(char nr)
{
  switch (nr)
  {
    case 0 :                                 // Font 12 x 16
      {
        txfnt.fresx= 12;                       // X-Achse = 12 Pixel
        txfnt.fresy= 16;                       // Y-Achse = 16 Pixel
        txfnt.flen= 32;                        // ein Zeichen hat eine Bitmapgroesse von 32 Bytes
        txfnt.fptr= &fnt12x16[0][0];           // Adresse des Zeichensatzes
        txfnt.fcolor= white;
        txfnt.modus= 1;
        break;
      }
    case 1 :                                 // Font 8 x 14
      {
        txfnt.fresx= 8;                        // X-Achse = 8 Pixel
        txfnt.fresy= 14;                       // Y-Achse = 14 Pixel
        txfnt.flen= 14;                        // ein Zeichen hat eine Bitmapgroesse von 14 Bytes
        txfnt.fptr= &fnt8x14[0][0];            // Adresse des Zeichensatzes
        txfnt.fcolor= white;
        txfnt.modus= 1;
        break;
      }
    default :
      {
        break;
      }
  }
}

// --------------------------------------------------
//                     TX_PUTCHAR
//    setzt einen grossen Buchstaben (Logo) auf den
//    Textbildschirm
// --------------------------------------------------
void tx_putchar(int ch, char c1, char c2)
{
  uint8_t rdby;
  int i, bx;
  uint8_t x,y;
  uint8_t wx, wy;

  x= txwherex; y= txwherey;
  wx= x; wy= y;
  if (txfnt.fresx > 8)
  {
    for (i= 0; i< txfnt.flen ; i+= 2)
    {
      rdby= txfnt.fptr[( ch * txfnt.flen ) + i+1];
      for (bx= (16-txfnt.fresx); bx< 8; bx++)
      {
        gotoxy(x,y);
        if ((rdby >> bx) & 1) { putchar(c1); }
                         else { putchar(c2); }
        x++;
      }
      rdby= txfnt.fptr[( ch * txfnt.flen ) + i];
      for (bx= 0; bx< 8; bx++)
      {
        gotoxy(x,y);
        if ((rdby >> bx) & 1) { putchar(c1); }
                         else { putchar(c2); }
        x++;
      }
      y++;
      x= wx;
    }
  }
  else
  {
    for (i= 0; i< txfnt.flen ; i++)
    {
      rdby= txfnt.fptr[( ch * txfnt.flen ) + i];
      for (bx= 0; bx< 8; bx++)
      {
        gotoxy(x,y);
        if ((rdby >> bx) & 1) { putchar(c1); }
                         else { putchar(c2); }
        x++;
      }
      y++;
      x= wx;
    }
  }
  gotoxy(wx+txfnt.fresx,wy);
}

//   --------------- TX_PUTSTRING -----------------
//     schreibt einen Text auf den Bildschirm, der
//     aus anderen Buchstaben zusammengesetzt wird
//   ----------------------------------------------
void tx_putstring(char x, char y, uint8_t f, char c1, char c2, unsigned char *c)
{
  uint8_t f2;

  f2= f;
  settextattr(f);
  txwherex= x; txwherey= y;

  while (*c) {tx_putchar(*c++,c1,c2);}
  settextattr(f2);
}

// ---------------------- GETCH -------------------
//   liest eine Taste von der Tastatur ein.
//   WICHTIG: es wird auf einen Tastendruck
//   gewartet, es wird die zuletzt gedrueckte Taste
//   zurueck gegeben.
// ------------------------------------------------
int getch(void)
{
  static int ch = -1, fd = 0;
  struct termios neu, alt;

  fd = fileno(stdin);
  tcgetattr(fd, &alt);
  neu = alt;
  neu.c_lflag &= ~(ICANON|ECHO);
  tcsetattr(fd, TCSANOW, &neu);
  ch = getchar();
  tcsetattr(fd, TCSANOW, &alt);
  ch &= 0xff;
  return ch;
}

// ---------------------- KEYPRESSED -------------------
//   Testet, ob eine Taste gedrueckt ist
//   WICHTIG: es wird NICHT auf einen Tastendruck
//   gewartet.
// ------------------------------------------------
int keypressed(void)
{
  struct termios alt, neu;
  int ch;
  int altf;

  tcgetattr(STDIN_FILENO, &alt);
  neu = alt;
  neu.c_lflag &= ~(ICANON | ECHO);
  tcsetattr(STDIN_FILENO, TCSANOW, &neu);
  altf = fcntl(STDIN_FILENO, F_GETFL, 0);
  fcntl(STDIN_FILENO, F_SETFL, altf | O_NONBLOCK);

  ch = getchar();

  tcsetattr(STDIN_FILENO, TCSANOW, &alt);
  fcntl(STDIN_FILENO, F_SETFL, altf);

  if(ch != EOF)
  {
    ungetc(ch, stdin);
    return 1;
  }

  return 0;
}

// ---------------------- READKEY -------------------
//   Liest Tastatur ein und unterscheidet auch
//   zwischen Cursor(Pfeil)-Tasten und den
//   F1 .. F12 Tasten. Rueckgabewert ist ein
//   unsigned int (der bspw. bei F6 bis F12 auch in
//   ALLEN Stellen in voller Laenge benoetigt wird).
// --------------------------------------------------
unsigned int readkey(void)
{
  int n;
  unsigned int ch,ch2;

  ch= getch();
  if (keypressed())
  {
    ch= 0;
    while(keypressed())
    {
      ch= (ch << 8) | getch();
    }
  }
  return ch;
}

// ---------------------------------------------------------
//                       FONT8x14
//    Bitmaps fuer einen Pixelschriftstil 8x14 Bildpunkte
// ---------------------------------------------------------

  char fnt8x14[256][14]={
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x00
  {0x00,0x00,0x00,0x00,0x3C,0x42,0xA5,0x81,0xBD,0x42,0x3C,0x00,0x00,0x00},        // 0x01
  {0x00,0x00,0x00,0x00,0x3C,0x7E,0xDB,0xFF,0xDB,0x42,0x3C,0x00,0x00,0x00},        // 0x02
  {0x00,0x66,0xFF,0xFF,0xFF,0xFF,0x7E,0x7E,0x3C,0x3C,0x18,0x00,0x00,0x00},        // 0x03
  {0x00,0x10,0x18,0x3C,0x7E,0xFF,0x7E,0x3C,0x38,0x10,0x10,0x00,0x00,0x00},        // 0x04
  {0x00,0x18,0x3C,0x3C,0x7E,0xFF,0xFF,0x6E,0x18,0x18,0x18,0x00,0x00,0x00},        // 0x05
  {0x00,0x10,0x18,0x38,0x7C,0xFE,0xFF,0xFF,0x6E,0x18,0x18,0x00,0x00,0x00},        // 0x06
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x07
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x08
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x09
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x0A
  {0x00,0x60,0xD0,0xA0,0x3C,0x22,0x41,0x41,0x41,0x22,0x1C,0x00,0x00,0x00},        // 0x0B
  {0x00,0x1C,0x22,0x41,0x41,0x41,0x22,0x1C,0x08,0x3E,0x08,0x00,0x00,0x00},        // 0x0C
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x0D
  {0x00,0x40,0x70,0x58,0x48,0x48,0x48,0x48,0x48,0x78,0x3E,0x0F,0x07,0x00},        // 0x0E
  {0x00,0x00,0x00,0x08,0x7E,0x46,0xC3,0x46,0x7E,0x08,0x00,0x00,0x00,0x00},        // 0x0F
  {0x00,0x00,0x00,0x01,0x07,0x3F,0xFF,0x3F,0x0F,0x07,0x01,0x00,0x00,0x00},        // 0x10
  {0x00,0x00,0x00,0x80,0xE0,0xFC,0xFF,0xFC,0xF0,0xE0,0x80,0x00,0x00,0x00},        // 0x11
  {0x00,0x10,0x38,0x54,0x10,0x10,0x10,0x10,0x10,0x10,0x54,0x38,0x10,0x00},        // 0x12
  {0x00,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x00,0x24,0x24,0x00,0x00,0x00},        // 0x13
  {0x00,0x7E,0x4F,0x4F,0x4F,0x4E,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x00},        // 0x14
  {0x00,0x78,0x04,0x04,0x1C,0x34,0x44,0x4C,0x38,0x60,0x40,0x44,0x3C,0x00},        // 0x15
  {0x00,0x00,0x00,0x00,0x00,0x7E,0x7E,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x16
  {0x10,0x38,0x54,0x10,0x10,0x10,0x10,0x10,0x10,0x54,0x38,0x10,0x00,0x7C},        // 0x17
  {0x00,0x10,0x38,0x54,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00},        // 0x18
  {0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x54,0x38,0x10,0x00},        // 0x19
  {0x00,0x00,0x00,0x00,0x10,0x20,0x7E,0x20,0x10,0x00,0x00,0x00,0x00,0x00},        // 0x1A
  {0x00,0x00,0x00,0x00,0x08,0x04,0x7E,0x04,0x08,0x00,0x00,0x00,0x00,0x00},        // 0x1B
  {0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x7E,0x00,0x00,0x00},        // 0x1C
  {0x00,0x00,0x00,0x00,0x00,0x24,0x7E,0x24,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x1D
  {0x00,0x00,0x00,0x10,0x10,0x38,0x38,0x3C,0x7E,0x7E,0xFF,0x00,0x00,0x00},        // 0x1E
  {0x00,0x00,0x00,0xFF,0x7E,0x7E,0x3C,0x38,0x38,0x10,0x10,0x00,0x00,0x00},        // 0x1F
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x20
  {0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x08,0x08,0x00,0x00,0x00},        // 0x21
  {0x24,0x24,0x24,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x22
  {0x00,0x90,0x90,0x48,0xFE,0x48,0x24,0xFF,0x24,0x12,0x12,0x00,0x00,0x00},        // 0x23
  {0x08,0x3C,0x0A,0x0A,0x0A,0x0C,0x18,0x28,0x28,0x28,0x1E,0x08,0x00,0x00},        // 0x24
  {0x00,0x86,0x49,0x29,0x29,0x16,0x68,0x94,0x94,0x92,0x61,0x00,0x00,0x00},        // 0x25
  {0x00,0x18,0x24,0x24,0x14,0x0C,0x8B,0x91,0x71,0x63,0xFE,0x00,0x00,0x00},        // 0x26
  {0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x27
  {0x60,0x30,0x08,0x08,0x04,0x04,0x04,0x04,0x04,0x08,0x08,0x30,0x60,0x00},        // 0x28
  {0x06,0x0C,0x10,0x10,0x20,0x20,0x20,0x20,0x20,0x10,0x10,0x0C,0x06,0x00},        // 0x29
  {0x00,0x08,0x08,0x66,0x14,0x2C,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x2A
  {0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x7F,0x08,0x08,0x08,0x00,0x00,0x00},        // 0x2B
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x10,0x08,0x00},        // 0x2C
  {0x00,0x00,0x00,0x00,0x00,0x00,0x7E,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x2D
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00},        // 0x2E
  {0x40,0x20,0x20,0x20,0x10,0x10,0x18,0x08,0x08,0x04,0x04,0x04,0x02,0x00},        // 0x2F
  {0x00,0x18,0x24,0x42,0x42,0x42,0x42,0x42,0x42,0x24,0x18,0x00,0x00,0x00},        // 0x30
  {0x00,0x10,0x1E,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xFE,0x00,0x00,0x00},        // 0x31
  {0x00,0x1E,0x20,0x20,0x20,0x10,0x10,0x08,0x04,0x02,0x3E,0x00,0x00,0x00},        // 0x32
  {0x00,0x3C,0x40,0x40,0x40,0x38,0x40,0x40,0x40,0x40,0x3C,0x00,0x00,0x00},        // 0x33
  {0x00,0x20,0x30,0x28,0x28,0x24,0x22,0x7E,0x20,0x20,0x20,0x00,0x00,0x00},        // 0x34
  {0x00,0x7C,0x04,0x04,0x04,0x1C,0x60,0x40,0x40,0x40,0x3C,0x00,0x00,0x00},        // 0x35
  {0x00,0x38,0x04,0x02,0x02,0x3A,0x46,0x42,0x42,0x44,0x38,0x00,0x00,0x00},        // 0x36
  {0x00,0x7E,0x40,0x20,0x20,0x10,0x08,0x08,0x08,0x04,0x04,0x00,0x00,0x00},        // 0x37
  {0x00,0x3C,0x42,0x42,0x22,0x1C,0x24,0x42,0x42,0x42,0x3C,0x00,0x00,0x00},        // 0x38
  {0x00,0x1C,0x22,0x42,0x42,0x62,0x5C,0x40,0x40,0x20,0x1C,0x00,0x00,0x00},        // 0x39
  {0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00},        // 0x3A
  {0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x18,0x18,0x10,0x08,0x00},        // 0x3B
  {0x00,0x00,0x00,0x00,0x40,0x30,0x08,0x06,0x08,0x30,0x40,0x00,0x00,0x00},        // 0x3C
  {0x00,0x00,0x00,0x00,0x00,0x7E,0x00,0x00,0x7E,0x00,0x00,0x00,0x00,0x00},        // 0x3D
  {0x00,0x00,0x00,0x00,0x02,0x0C,0x10,0x60,0x10,0x0C,0x02,0x00,0x00,0x00},        // 0x3E
  {0x00,0x3E,0x42,0x40,0x20,0x10,0x08,0x08,0x00,0x08,0x08,0x00,0x00,0x00},        // 0x3F
  {0x00,0x3C,0x46,0x72,0x49,0x49,0x49,0x69,0xDB,0x22,0x3C,0x00,0x00,0x00},        // 0x40
  {0x00,0x00,0x10,0x18,0x28,0x24,0x24,0x42,0x7E,0x42,0x81,0x00,0x00,0x00},        // 0x41 A
  {0x00,0x00,0x3E,0x42,0x42,0x22,0x1E,0x22,0x42,0x42,0x3E,0x00,0x00,0x00},        // 0x42 B
  {0x00,0x00,0x7C,0x02,0x01,0x01,0x01,0x01,0x01,0x02,0x7C,0x00,0x00,0x00},        // 0x43 C
  {0x00,0x00,0x1F,0x21,0x41,0x41,0x41,0x41,0x41,0x21,0x1F,0x00,0x00,0x00},        // 0x44 D
  {0x00,0x00,0x7E,0x02,0x02,0x02,0x3E,0x02,0x02,0x02,0x7E,0x00,0x00,0x00},        // 0x45 E
  {0x00,0x00,0x7E,0x02,0x02,0x02,0x3E,0x02,0x02,0x02,0x02,0x00,0x00,0x00},        // 0x46 F
  {0x00,0x00,0x7C,0x02,0x01,0x01,0x01,0x71,0x41,0x42,0x7C,0x00,0x00,0x00},        // 0x47 G
  {0x00,0x00,0x42,0x42,0x42,0x42,0x7E,0x42,0x42,0x42,0x42,0x00,0x00,0x00},        // 0x48
  {0x00,0x00,0x3E,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3E,0x00,0x00,0x00},        // 0x49
  {0x00,0x00,0x3C,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1E,0x00,0x00,0x00},        // 0x4A
  {0x00,0x00,0x42,0x22,0x12,0x0A,0x06,0x0A,0x12,0x22,0x42,0x00,0x00,0x00},        // 0x4B
  {0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x7E,0x00,0x00,0x00},        // 0x4C
  {0x00,0x00,0x63,0x63,0x63,0x55,0x55,0x55,0x49,0x41,0x41,0x00,0x00,0x00},        // 0x4D
  {0x00,0x00,0x42,0x46,0x46,0x4A,0x4A,0x52,0x52,0x62,0x42,0x00,0x00,0x00},        // 0x4E
  {0x00,0x00,0x1C,0x22,0x41,0x41,0x41,0x41,0x41,0x22,0x1C,0x00,0x00,0x00},        // 0x4F
  {0x00,0x00,0x3E,0x42,0x42,0x42,0x62,0x1E,0x02,0x02,0x02,0x00,0x00,0x00},        // 0x50
  {0x00,0x00,0x1C,0x22,0x41,0x41,0x41,0x41,0x41,0x22,0x1C,0x60,0xC0,0x00},        // 0x51
  {0x00,0x00,0x1E,0x22,0x22,0x22,0x1E,0x12,0x32,0x22,0x42,0x00,0x00,0x00},        // 0x52
  {0x00,0x00,0x7C,0x02,0x02,0x06,0x18,0x60,0x40,0x40,0x3E,0x00,0x00,0x00},        // 0x53
  {0x00,0x00,0x7F,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00},        // 0x54
  {0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3C,0x00,0x00,0x00},        // 0x55
  {0x00,0x00,0x81,0x42,0x42,0x22,0x24,0x14,0x14,0x08,0x08,0x00,0x00,0x00},        // 0x56
  {0x00,0x00,0x81,0x81,0xC9,0x59,0x5A,0x5A,0x66,0x66,0x24,0x00,0x00,0x00},        // 0x57
  {0x00,0x00,0x81,0x42,0x24,0x18,0x18,0x18,0x24,0x42,0x81,0x00,0x00,0x00},        // 0x58
  {0x00,0x00,0x81,0x42,0x22,0x14,0x18,0x08,0x08,0x08,0x08,0x00,0x00,0x00},        // 0x59
  {0x00,0x00,0x7F,0x40,0x20,0x10,0x08,0x04,0x02,0x01,0x7F,0x00,0x00,0x00},        // 0x5A
  {0x78,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x78,0x00},        // 0x5B
  {0x02,0x04,0x04,0x04,0x08,0x08,0x18,0x10,0x10,0x20,0x20,0x20,0x40,0x00},        // 0x5C
  {0x1E,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1E,0x00},        // 0x5D
  {0x00,0x10,0x10,0x18,0x28,0x28,0x24,0x44,0x42,0x00,0x00,0x00,0x00,0x00},        // 0x5E
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00},        // 0x5F
  {0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x60
  {0x00,0x00,0x00,0x00,0x3C,0x40,0x40,0x7C,0x42,0x42,0xFC,0x00,0x00,0x00},        // 0x61
  {0x02,0x02,0x02,0x02,0x3A,0x46,0x42,0x42,0x42,0x46,0x3A,0x00,0x00,0x00},        // 0x62
  {0x00,0x00,0x00,0x00,0x78,0x04,0x02,0x02,0x02,0x04,0x78,0x00,0x00,0x00},        // 0x63
  {0x40,0x40,0x40,0x40,0x5C,0x62,0x42,0x42,0x42,0x62,0x5C,0x00,0x00,0x00},        // 0x64
  {0x00,0x00,0x00,0x00,0x3C,0x44,0x42,0x7E,0x02,0x02,0x7C,0x00,0x00,0x00},        // 0x65
  {0x70,0x08,0x08,0x08,0x7E,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00},        // 0x66
  {0x00,0x00,0x00,0x00,0x7C,0x62,0x42,0x42,0x42,0x62,0x5C,0x40,0x40,0x3C},        // 0x67
  {0x02,0x02,0x02,0x02,0x3A,0x46,0x42,0x42,0x42,0x42,0x42,0x00,0x00,0x00},        // 0x68
  {0x18,0x18,0x00,0x00,0x1E,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00},        // 0x69
  {0x30,0x30,0x00,0x00,0x3C,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1E},        // 0x6A
  {0x02,0x02,0x02,0x02,0x22,0x12,0x0A,0x06,0x1A,0x22,0x42,0x00,0x00,0x00},        // 0x6B
  {0x1E,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00},        // 0x6C
  {0x00,0x00,0x00,0x00,0x6D,0x5B,0x49,0x49,0x49,0x49,0x49,0x00,0x00,0x00},        // 0x6D
  {0x00,0x00,0x00,0x00,0x3A,0x46,0x42,0x42,0x42,0x42,0x42,0x00,0x00,0x00},        // 0x6E
  {0x00,0x00,0x00,0x00,0x1C,0x22,0x41,0x41,0x41,0x22,0x1C,0x00,0x00,0x00},        // 0x6F
  {0x00,0x00,0x00,0x00,0x3A,0x46,0x42,0x42,0x42,0x46,0x3A,0x02,0x02,0x02},        // 0x70
  {0x00,0x00,0x00,0x00,0x5C,0x62,0x42,0x42,0x42,0x62,0x5C,0x40,0x40,0x40},        // 0x71
  {0x00,0x00,0x00,0x00,0x3A,0x26,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00},        // 0x72
  {0x00,0x00,0x00,0x00,0x3C,0x02,0x06,0x18,0x20,0x20,0x1E,0x00,0x00,0x00},        // 0x73
  {0x00,0x00,0x04,0x04,0x7F,0x04,0x04,0x04,0x04,0x04,0x78,0x00,0x00,0x00},        // 0x74
  {0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x62,0x5C,0x00,0x00,0x00},        // 0x75
  {0x00,0x00,0x00,0x00,0x81,0x42,0x42,0x22,0x14,0x14,0x08,0x00,0x00,0x00},        // 0x76
  {0x00,0x00,0x00,0x00,0x81,0x91,0x5A,0x5A,0x66,0x24,0x24,0x00,0x00,0x00},        // 0x77
  {0x00,0x00,0x00,0x00,0x42,0x24,0x18,0x18,0x18,0x24,0x42,0x00,0x00,0x00},        // 0x78
  {0x00,0x00,0x00,0x00,0x81,0x42,0x42,0x24,0x24,0x18,0x18,0x08,0x0C,0x07},        // 0x79
  {0x00,0x00,0x00,0x00,0x7F,0x20,0x10,0x08,0x04,0x02,0x7F,0x00,0x00,0x00},        // 0x7A
  {0x70,0x08,0x08,0x08,0x08,0x08,0x06,0x08,0x08,0x08,0x08,0x08,0x70,0x00},        // 0x7B
  {0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00},        // 0x7C
  {0x0E,0x10,0x10,0x10,0x10,0x10,0x60,0x10,0x10,0x10,0x10,0x10,0x0E,0x00},        // 0x7D
  {0x00,0x00,0x00,0x00,0x00,0x86,0x99,0x61,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x7E
  {0x00,0x00,0x00,0x08,0x1C,0x22,0x41,0x41,0x41,0x41,0x7F,0x00,0x00,0x00},        // 0x7F
  {0x00,0x00,0x7C,0x02,0x01,0x01,0x01,0x01,0x01,0x02,0x7C,0x10,0x20,0x30},        // 0x80
  {0x00,0x24,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x62,0x5C,0x00,0x00,0x00},        // 0x81
  {0x20,0x10,0x00,0x00,0x3C,0x44,0x42,0x7E,0x02,0x02,0x7C,0x00,0x00,0x00},        // 0x82
  {0x18,0x24,0x00,0x00,0x3C,0x40,0x40,0x7C,0x42,0x42,0xFC,0x00,0x00,0x00},        // 0x83
  {0x00,0x24,0x00,0x00,0x3C,0x40,0x40,0x7C,0x42,0x42,0xFC,0x00,0x00,0x00},        // 0x84
  {0x08,0x10,0x00,0x00,0x3C,0x40,0x40,0x7C,0x42,0x42,0xFC,0x00,0x00,0x00},        // 0x85
  {0x10,0x28,0x10,0x00,0x3C,0x40,0x40,0x7C,0x42,0x42,0xFC,0x00,0x00,0x00},        // 0x86
  {0x00,0x00,0x00,0x00,0x78,0x04,0x02,0x02,0x02,0x04,0x78,0x08,0x10,0x18},        // 0x87
  {0x18,0x24,0x00,0x00,0x3C,0x44,0x42,0x7E,0x02,0x02,0x7C,0x00,0x00,0x00},        // 0x88
  {0x00,0x48,0x00,0x00,0x3C,0x44,0x42,0x7E,0x02,0x02,0x7C,0x00,0x00,0x00},        // 0x89
  {0x08,0x10,0x00,0x00,0x3C,0x44,0x42,0x7E,0x02,0x02,0x7C,0x00,0x00,0x00},        // 0x8A
  {0x00,0x24,0x00,0x00,0x1E,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00},        // 0x8B
  {0x18,0x24,0x00,0x00,0x1E,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00},        // 0x8C
  {0x08,0x10,0x00,0x00,0x1E,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00},        // 0x8D
  {0x24,0x00,0x10,0x18,0x28,0x24,0x24,0x42,0x7E,0x42,0x81,0x00,0x00,0x00},        // 0x8E
  {0x08,0x14,0x08,0x1C,0x14,0x34,0x22,0x22,0x7E,0x43,0x81,0x00,0x00,0x00},        // 0x8F
  {0x20,0x10,0x7E,0x02,0x02,0x02,0x3E,0x02,0x02,0x02,0x7E,0x00,0x00,0x00},        // 0x90
  {0x00,0x00,0x00,0x00,0x77,0x88,0x88,0xFE,0x09,0x09,0xF6,0x00,0x00,0x00},        // 0x91
  {0x00,0x00,0xF0,0x18,0x18,0x14,0x74,0x12,0x1E,0x12,0xF1,0x00,0x00,0x00},        // 0x92
  {0x18,0x24,0x00,0x00,0x1C,0x22,0x41,0x41,0x41,0x22,0x1C,0x00,0x00,0x00},        // 0x93
  {0x00,0x24,0x00,0x00,0x1C,0x22,0x41,0x41,0x41,0x22,0x1C,0x00,0x00,0x00},        // 0x94
  {0x04,0x08,0x00,0x00,0x1C,0x22,0x41,0x41,0x41,0x22,0x1C,0x00,0x00,0x00},        // 0x95
  {0x18,0x24,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x62,0x5C,0x00,0x00,0x00},        // 0x96
  {0x04,0x08,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x62,0x5C,0x00,0x00,0x00},        // 0x97
  {0x00,0x24,0x00,0x00,0x81,0x42,0x42,0x24,0x24,0x18,0x18,0x08,0x0C,0x07},        // 0x98
  {0x24,0x00,0x1C,0x22,0x41,0x41,0x41,0x41,0x41,0x22,0x1C,0x00,0x00,0x00},        // 0x99
  {0x24,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3C,0x00,0x00,0x00},        // 0x9A
  {0x00,0x00,0x00,0x00,0x7E,0x63,0x51,0x49,0x45,0x22,0x1F,0x00,0x00,0x00},        // 0x9B
  {0x00,0x70,0x08,0x08,0x08,0x1C,0x08,0x08,0x08,0x04,0x7C,0x00,0x00,0x00},        // 0x9C
  {0x00,0x00,0x5C,0x22,0x61,0x51,0x49,0x45,0x43,0x22,0x1D,0x00,0x00,0x00},        // 0x9D
  {0x00,0x00,0x00,0x00,0x41,0x22,0x14,0x08,0x14,0x22,0x41,0x00,0x00,0x00},        // 0x9E
  {0x70,0x08,0x08,0x08,0x3C,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x07},        // 0x9F
  {0x20,0x10,0x00,0x00,0x3C,0x40,0x40,0x7C,0x42,0x42,0xFC,0x00,0x00,0x00},        // 0xA0
  {0x20,0x10,0x00,0x00,0x1E,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00},        // 0xA1
  {0x20,0x10,0x00,0x00,0x1C,0x22,0x41,0x41,0x41,0x22,0x1C,0x00,0x00,0x00},        // 0xA2
  {0x20,0x10,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x62,0x5C,0x00,0x00,0x00},        // 0xA3
  {0x48,0x34,0x00,0x00,0x3A,0x46,0x42,0x42,0x42,0x42,0x42,0x00,0x00,0x00},        // 0xA4
  {0x58,0x34,0x42,0x46,0x46,0x4A,0x4A,0x52,0x52,0x62,0x42,0x00,0x00,0x00},        // 0xA5
  {0x00,0x3C,0x20,0x38,0x24,0x7C,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xA6
  {0x00,0x1C,0x22,0x22,0x22,0x1C,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xA7
  {0x00,0x00,0x00,0x00,0x10,0x10,0x00,0x10,0x10,0x08,0x04,0x02,0x42,0x7C},        // 0xA8
  {0x00,0x3C,0x42,0x5A,0x5A,0x42,0x3C,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xA9
  {0x00,0x00,0x00,0x00,0x00,0x00,0x7F,0x40,0x40,0x00,0x00,0x00,0x00,0x00},        // 0xAA
  {0x00,0x43,0x22,0x32,0x12,0x0A,0xF8,0x84,0x46,0x32,0xF1,0x00,0x00,0x00},        // 0xAB
  {0x00,0x43,0x22,0x12,0x12,0x0A,0x68,0x54,0x4A,0xFA,0x41,0x00,0x00,0x00},        // 0xAC
  {0x00,0x00,0x00,0x00,0x08,0x08,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08},        // 0xAD
  {0x00,0x00,0x00,0x00,0x48,0x24,0x12,0x12,0x24,0x48,0x00,0x00,0x00,0x00},        // 0xAE
  {0x00,0x00,0x00,0x00,0x12,0x24,0x48,0x48,0x24,0x12,0x00,0x00,0x00,0x00},        // 0xAF
  {0x49,0x00,0x00,0x49,0x00,0x00,0x49,0x00,0x49,0x00,0x00,0x49,0x00,0x00},        // 0xB0
  {0x92,0x49,0x00,0x92,0x49,0x00,0x92,0x49,0x92,0x00,0x49,0x92,0x00,0x49},        // 0xB1
  {0xFF,0x49,0x49,0xFF,0x49,0x49,0xFF,0x49,0xFF,0x49,0x49,0xFF,0x49,0x49},        // 0xB2
  {0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10},        // 0xB3
  {0x10,0x10,0x10,0x10,0x10,0x10,0x1F,0x10,0x10,0x10,0x10,0x10,0x10,0x10},        // 0xB4
  {0x10,0x08,0x10,0x18,0x28,0x24,0x24,0x42,0x7E,0x42,0x81,0x00,0x00,0x00},        // 0xB5
  {0x18,0x24,0x10,0x18,0x28,0x24,0x24,0x42,0x7E,0x42,0x81,0x00,0x00,0x00},        // 0xB6
  {0x08,0x10,0x10,0x18,0x28,0x24,0x24,0x42,0x7E,0x42,0x81,0x00,0x00,0x00},        // 0xB7
  {0x00,0x3C,0x42,0xB9,0x85,0x85,0x85,0x85,0xB9,0x42,0x3C,0x00,0x00,0x00},        // 0xB8
  {0x28,0x28,0x28,0x28,0x28,0x2F,0x20,0x2F,0x28,0x28,0x28,0x28,0x28,0x28},        // 0xB9
  {0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28},        // 0xBA
  {0x00,0x00,0x00,0x00,0x00,0x3F,0x20,0x2F,0x28,0x28,0x28,0x28,0x28,0x28},        // 0xBB
  {0x28,0x28,0x28,0x28,0x28,0x2F,0x20,0x3F,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xBC
  {0x00,0x10,0x78,0x14,0x12,0x12,0x12,0x12,0x14,0x78,0x10,0x00,0x00,0x00},        // 0xBD
  {0x00,0x81,0x42,0x24,0x14,0x08,0x3E,0x08,0x3E,0x08,0x08,0x00,0x00,0x00},        // 0xBE
  {0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0x10,0x10,0x10,0x10,0x10,0x10,0x10},        // 0xBF
  {0x10,0x10,0x10,0x10,0x10,0x10,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xC0
  {0x10,0x10,0x10,0x10,0x10,0x10,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xC1
  {0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x10,0x10,0x10,0x10,0x10,0x10,0x10},        // 0xC2
  {0x10,0x10,0x10,0x10,0x10,0x10,0xF0,0x10,0x10,0x10,0x10,0x10,0x10,0x10},        // 0xC3
  {0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xC4
  {0x10,0x10,0x10,0x10,0x10,0x10,0xFF,0x10,0x10,0x10,0x10,0x10,0x10,0x10},        // 0xC5
  {0x48,0x34,0x00,0x00,0x3C,0x40,0x40,0x7C,0x42,0x42,0xFC,0x00,0x00,0x00},        // 0xC6
  {0x58,0x34,0x10,0x18,0x28,0x24,0x24,0x42,0x7E,0x42,0x81,0x00,0x00,0x00},        // 0xC7
  {0x28,0x28,0x28,0x28,0x28,0xE8,0x08,0xF8,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xC8
  {0x00,0x00,0x00,0x00,0x00,0xF8,0x08,0xE8,0x28,0x28,0x28,0x28,0x28,0x28},        // 0xC9
  {0x28,0x28,0x28,0x28,0x28,0xEF,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xCA
  {0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0xEF,0x28,0x28,0x28,0x28,0x28,0x28},        // 0xCB
  {0x28,0x28,0x28,0x28,0x28,0xE8,0x08,0xE8,0x28,0x28,0x28,0x28,0x28,0x28},        // 0xCC
  {0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xCD
  {0x28,0x28,0x28,0x28,0x28,0xEF,0x00,0xEF,0x28,0x28,0x28,0x28,0x28,0x28},        // 0xCE
  {0x00,0x00,0x41,0x3E,0x22,0x22,0x22,0x22,0x3E,0x41,0x00,0x00,0x00,0x00},        // 0xCF
  {0x17,0x0C,0x16,0x20,0x3C,0x62,0x41,0x41,0x41,0x22,0x1C,0x00,0x00,0x00},        // 0xD0
  {0x00,0x00,0x3E,0x42,0x82,0x82,0x8F,0x82,0x82,0x42,0x3E,0x00,0x00,0x00},        // 0xD1
  {0x18,0x24,0x7E,0x02,0x02,0x02,0x3E,0x02,0x02,0x02,0x7E,0x00,0x00,0x00},        // 0xD2
  {0x24,0x00,0x7E,0x02,0x02,0x02,0x3E,0x02,0x02,0x02,0x7E,0x00,0x00,0x00},        // 0xD3
  {0x10,0x20,0x7E,0x02,0x02,0x02,0x3E,0x02,0x02,0x02,0x7E,0x00,0x00,0x00},        // 0xD4
  {0x00,0x00,0x00,0x00,0x1E,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00},        // 0xD5
  {0x20,0x10,0x3E,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3E,0x00,0x00,0x00},        // 0xD6
  {0x18,0x24,0x3E,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3E,0x00,0x00,0x00},        // 0xD7
  {0x24,0x00,0x3E,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3E,0x00,0x00,0x00},        // 0xD8
  {0x10,0x10,0x10,0x10,0x10,0x10,0x1F,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xD9
  {0x00,0x00,0x00,0x00,0x00,0x00,0xF0,0x10,0x10,0x10,0x10,0x10,0x10,0x10},        // 0xDA
  {0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF},        // 0xDB
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF},        // 0xDC
  {0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x00},        // 0xDD
  {0x08,0x10,0x3E,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3E,0x00,0x00,0x00},        // 0xDE
  {0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xDF
  {0x20,0x10,0x1C,0x22,0x41,0x41,0x41,0x41,0x41,0x22,0x1C,0x00,0x00,0x00},        // 0xE0
  {0x1C,0x22,0x22,0x22,0x12,0x12,0x22,0x42,0x82,0x82,0x72,0x00,0x00,0x00},        // 0xE1
  {0x18,0x24,0x1C,0x22,0x41,0x41,0x41,0x41,0x41,0x22,0x1C,0x00,0x00,0x00},        // 0xE2
  {0x08,0x10,0x1C,0x22,0x41,0x41,0x41,0x41,0x41,0x22,0x1C,0x00,0x00,0x00},        // 0xE3
  {0x48,0x34,0x00,0x00,0x1C,0x22,0x41,0x41,0x41,0x22,0x1C,0x00,0x00,0x00},        // 0xE4
  {0x58,0x34,0x1C,0x22,0x41,0x41,0x41,0x41,0x41,0x22,0x1C,0x00,0x00,0x00},        // 0xE5
  {0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x66,0x5A,0x02,0x02,0x02},        // 0xE6
  {0x02,0x02,0x02,0x02,0x3A,0x46,0x42,0x42,0x42,0x46,0x3A,0x02,0x02,0x02},        // 0xE7
  {0x00,0x00,0x02,0x02,0x3E,0x42,0x42,0x42,0x3E,0x02,0x02,0x00,0x00,0x00},        // 0xE8
  {0x20,0x10,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3C,0x00,0x00,0x00},        // 0xE9
  {0x18,0x24,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3C,0x00,0x00,0x00},        // 0xEA
  {0x10,0x20,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3C,0x00,0x00,0x00},        // 0xEB
  {0x20,0x10,0x00,0x00,0x81,0x42,0x42,0x24,0x24,0x18,0x18,0x08,0x0C,0x07},        // 0xEC
  {0x20,0x10,0x81,0x42,0x22,0x14,0x18,0x08,0x08,0x08,0x08,0x00,0x00,0x00},        // 0xED
  {0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xEE
  {0x10,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xEF
  {0x00,0x00,0x00,0x00,0x00,0x00,0x7E,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xF0
  {0x00,0x00,0x00,0x00,0x08,0x08,0x7F,0x08,0x08,0x00,0x7F,0x00,0x00,0x00},        // 0xF1
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0xFF},        // 0xF2
  {0x00,0x87,0x44,0x23,0x24,0x17,0x68,0x54,0x4C,0xFA,0x41,0x00,0x00,0x00},        // 0xF3
  {0x00,0x7E,0x4F,0x4F,0x4F,0x4E,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x00},        // 0xF4
  {0x00,0x78,0x04,0x04,0x1C,0x34,0x44,0x4C,0x38,0x60,0x40,0x44,0x3C,0x00},        // 0xF5
  {0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x7F,0x00,0x18,0x18,0x00,0x00,0x00},        // 0xF6
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x18},        // 0xF7
  {0x00,0x08,0x14,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xF8
  {0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xF9
  {0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xFA
  {0x00,0x18,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xFB
  {0x00,0x3C,0x20,0x18,0x20,0x3C,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xFC
  {0x00,0x3C,0x20,0x10,0x08,0x3C,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xFD
  {0x00,0x00,0x00,0x00,0x7E,0x7E,0x7E,0x7E,0x7E,0x7E,0x7E,0x00,0x00,0x00},        // 0xFE
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}         // 0xFF
  };

// ---------------------------------------------------------
//                       FONT12x16
//    Bitmaps fuer einen Pixelschriftstil 12x16 Bildpunkte
// ---------------------------------------------------------

  char fnt12x16 [256][32]={
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x00
  {0x0E,0x00,0x31,0x80,0x40,0x40,0x40,0x40,0x9B,0x20,0x9B,0x20,0x80,0x20,0x80,0x20,0x91,0x20,0x8E,0x20,0x40,0x40,0x40,0x40,0x31,0x80,0x0E,0x00,0x00,0x00,0x00,0x00},        // 0x01
  {0x0E,0x00,0x3F,0x80,0x7F,0xC0,0x7F,0xC0,0xE4,0xE0,0xE4,0xE0,0xFF,0xE0,0xFF,0xE0,0xEE,0xE0,0xF1,0xE0,0x7F,0xC0,0x7F,0xC0,0x3F,0x80,0x0E,0x00,0x00,0x00,0x00,0x00},        // 0x02
  {0x00,0x00,0x00,0x00,0x00,0x00,0x31,0x80,0x7B,0xC0,0x7F,0xC0,0x7F,0xC0,0x7F,0xC0,0x3F,0x80,0x1F,0x00,0x0E,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x03
  {0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x0E,0x00,0x1F,0x00,0x3F,0x80,0x7F,0xC0,0x3F,0x80,0x1F,0x00,0x0E,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x04
  {0x00,0x00,0x00,0x00,0x0E,0x00,0x1F,0x00,0x1F,0x00,0x1F,0x00,0x6E,0xC0,0xFF,0xE0,0xFF,0xE0,0xFF,0xE0,0x64,0xC0,0x0E,0x00,0x1F,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x05
  {0x00,0x00,0x00,0x00,0x04,0x00,0x04,0x00,0x0E,0x00,0x1F,0x00,0x3F,0x80,0x7F,0xC0,0x7F,0xC0,0x7F,0xC0,0x35,0x80,0x0E,0x00,0x1F,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x06
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x07
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x08
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x09
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x0A
  {0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x00,0x60,0x00,0x57,0x80,0x4C,0xC0,0x18,0x60,0x18,0x60,0x18,0x60,0x0C,0xC0,0x07,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x0B
  {0x00,0x00,0x00,0x00,0x1E,0x00,0x33,0x00,0x61,0x80,0x61,0x80,0x61,0x80,0x33,0x00,0x1E,0x00,0x0C,0x00,0x0C,0x00,0x3F,0x00,0x0C,0x00,0x0C,0x00,0x00,0x00,0x00,0x00},        // 0x0C
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x0D
  {0x03,0x00,0x07,0x00,0x0D,0x00,0x19,0x00,0x33,0x00,0x27,0x00,0x2D,0x00,0x39,0x00,0x31,0xC0,0x21,0xE0,0x21,0xE0,0x38,0xC0,0x3C,0x00,0x3C,0x00,0x18,0x00,0x00,0x00},        // 0x0E
  {0x00,0x00,0x04,0x00,0x04,0x00,0x4E,0x40,0x3F,0x80,0x31,0x80,0x60,0xC0,0xE0,0xE0,0x60,0xC0,0x31,0x80,0x3F,0x80,0x4E,0x40,0x04,0x00,0x04,0x00,0x00,0x00,0x00,0x00},        // 0x0F
  {0x00,0x00,0x00,0x00,0x00,0x80,0x01,0x80,0x03,0x80,0x07,0x80,0x0F,0x80,0x1F,0x80,0x0F,0x80,0x07,0x80,0x03,0x80,0x01,0x80,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x10
  {0x00,0x00,0x00,0x00,0x10,0x00,0x18,0x00,0x1C,0x00,0x1E,0x00,0x1F,0x00,0x1F,0x80,0x1F,0x00,0x1E,0x00,0x1C,0x00,0x18,0x00,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x11
  {0x00,0x00,0x04,0x00,0x0E,0x00,0x1F,0x00,0x3F,0x80,0x04,0x00,0x04,0x00,0x04,0x00,0x04,0x00,0x04,0x00,0x3F,0x80,0x1F,0x00,0x0E,0x00,0x04,0x00,0x00,0x00,0x00,0x00},        // 0x12
  {0x00,0x00,0x19,0x80,0x19,0x80,0x19,0x80,0x19,0x80,0x19,0x80,0x19,0x80,0x19,0x80,0x19,0x80,0x19,0x80,0x19,0x80,0x00,0x00,0x19,0x80,0x19,0x80,0x00,0x00,0x00,0x00},        // 0x13
  {0x00,0x00,0x7F,0x80,0x36,0xC0,0x36,0x60,0x36,0x60,0x36,0x60,0x36,0xC0,0x37,0x80,0x36,0x00,0x36,0x00,0x36,0x00,0x36,0x00,0x36,0x00,0x36,0x00,0x00,0x00,0x00,0x00},        // 0x14
  {0x00,0x00,0x1F,0x80,0x30,0xC0,0x00,0xC0,0x00,0xC0,0x1F,0x80,0x30,0xC0,0x30,0xC0,0x1F,0x80,0x30,0x00,0x30,0x00,0x30,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x15
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7F,0x80,0x7F,0x80,0x7F,0x80,0x00,0x00,0x00,0x00},        // 0x16
  {0x04,0x00,0x0E,0x00,0x1F,0x00,0x3F,0x80,0x04,0x00,0x04,0x00,0x04,0x00,0x04,0x00,0x04,0x00,0x04,0x00,0x3F,0x80,0x1F,0x00,0x0E,0x00,0x04,0x00,0x3F,0x80,0x00,0x00},        // 0x17
  {0x00,0x00,0x04,0x00,0x0E,0x00,0x1F,0x00,0x3F,0x80,0x04,0x00,0x04,0x00,0x04,0x00,0x04,0x00,0x04,0x00,0x04,0x00,0x04,0x00,0x04,0x00,0x04,0x00,0x00,0x00,0x00,0x00},        // 0x18
  {0x00,0x00,0x04,0x00,0x04,0x00,0x04,0x00,0x04,0x00,0x04,0x00,0x04,0x00,0x04,0x00,0x04,0x00,0x04,0x00,0x3F,0x80,0x1F,0x00,0x0E,0x00,0x04,0x00,0x00,0x00,0x00,0x00},        // 0x19
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x18,0x00,0x38,0x00,0x7F,0xC0,0x38,0x00,0x18,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x1A
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x00,0x03,0x00,0x03,0x80,0x7F,0xC0,0x03,0x80,0x03,0x00,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x1B
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x20,0x00,0x20,0x00,0x20,0x00,0x20,0x7F,0xE0,0x00,0x00,0x00,0x00},        // 0x1C
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x11,0x00,0x31,0x80,0x71,0xC0,0xFF,0xE0,0x71,0xC0,0x31,0x80,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x1D
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x0E,0x00,0x1F,0x00,0x3F,0x80,0x7F,0xC0,0xFF,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x1E
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xE0,0x7F,0xC0,0x3F,0x80,0x1F,0x00,0x0E,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x1F
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x20
  {0x06,0x00,0x06,0x00,0x0F,0x00,0x0F,0x00,0x0F,0x00,0x0F,0x00,0x0F,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x06,0x00,0x00,0x00,0x00,0x00},        // 0x21
  {0x00,0x00,0x00,0x00,0x19,0x80,0x19,0x80,0x19,0x80,0x19,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x22
  {0x00,0x00,0x66,0x00,0x66,0x00,0x66,0x00,0xFF,0xC0,0x33,0x00,0x33,0x00,0x19,0x80,0x19,0x80,0x3F,0xE0,0x0C,0xC0,0x0C,0xC0,0x0C,0xC0,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x23
  {0x06,0x00,0x06,0x00,0x1F,0x80,0x3F,0xC0,0x06,0xC0,0x06,0xC0,0x1F,0xC0,0x3F,0x80,0x36,0x00,0x36,0x00,0x3F,0xC0,0x1F,0x80,0x06,0x00,0x06,0x00,0x00,0x00,0x00,0x00},        // 0x24
  {0x00,0x00,0x00,0x00,0x80,0x00,0xC1,0xC0,0xE1,0xC0,0x71,0xC0,0x38,0x00,0x1C,0x00,0x0E,0x00,0x07,0x00,0x03,0x80,0x71,0xC0,0x70,0xE0,0x70,0x60,0x00,0x00,0x00,0x00},        // 0x25
  {0x00,0x00,0x0E,0x00,0x1B,0x00,0x19,0x80,0x19,0x80,0x0D,0x80,0x07,0x00,0x07,0x80,0x07,0xC0,0x6C,0xC0,0x3C,0xC0,0x18,0xC0,0x3D,0xC0,0x67,0x80,0x00,0x00,0x00,0x00},        // 0x26
  {0x07,0x00,0x07,0x00,0x07,0x00,0x06,0x00,0x06,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x27
  {0x1C,0x00,0x06,0x00,0x07,0x00,0x03,0x00,0x03,0x80,0x03,0x80,0x03,0x80,0x03,0x80,0x03,0x80,0x03,0x80,0x03,0x00,0x07,0x00,0x06,0x00,0x1C,0x00,0x00,0x00,0x00,0x00},        // 0x28
  {0x03,0x80,0x06,0x00,0x0E,0x00,0x0C,0x00,0x1C,0x00,0x1C,0x00,0x1C,0x00,0x1C,0x00,0x1C,0x00,0x1C,0x00,0x0C,0x00,0x0E,0x00,0x06,0x00,0x03,0x80,0x00,0x00,0x00,0x00},        // 0x29
  {0x00,0x00,0x00,0x00,0x00,0x00,0x36,0xC0,0x36,0xC0,0x1F,0x80,0x0F,0x00,0x3F,0xC0,0x0F,0x00,0x1F,0x80,0x36,0xC0,0x36,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x2A
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x3F,0xC0,0x3F,0xC0,0x06,0x00,0x06,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x2B
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x07,0x00,0x07,0x00,0x06,0x00,0x03,0x00},        // 0x2C
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0xC0,0x3F,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x2D
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x07,0x00,0x07,0x00,0x00,0x00,0x00,0x00},        // 0x2E
  {0x00,0x00,0x80,0x00,0xC0,0x00,0xE0,0x00,0x70,0x00,0x38,0x00,0x1C,0x00,0x0E,0x00,0x07,0x00,0x03,0x80,0x01,0xC0,0x00,0xE0,0x00,0x60,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x2F
  {0x1F,0x00,0x7F,0xC0,0x60,0xC0,0xE0,0x60,0xF0,0x60,0xD8,0x60,0xCC,0x60,0xC6,0x60,0xC3,0x60,0xC1,0xE0,0xC0,0xE0,0x60,0xC0,0x7F,0xC0,0x1F,0x00,0x00,0x00,0x00,0x00},        // 0x30
  {0x0C,0x00,0x0E,0x00,0x0F,0x80,0x0F,0x80,0x0C,0x00,0x0C,0x00,0x0C,0x00,0x0C,0x00,0x0C,0x00,0x0C,0x00,0x0C,0x00,0x0C,0x00,0x7F,0x80,0x7F,0x80,0x00,0x00,0x00,0x00},        // 0x31
  {0x3F,0x80,0x7F,0xC0,0xE0,0xE0,0xC0,0x60,0xE0,0x60,0x70,0x00,0x38,0x00,0x1C,0x00,0x0E,0x00,0x07,0x00,0x03,0x80,0x01,0xC0,0xFF,0xE0,0xFF,0xE0,0x00,0x00,0x00,0x00},        // 0x32
  {0x3F,0x80,0x7F,0xC0,0xE0,0xE0,0xC0,0x60,0xC0,0x00,0xE0,0x00,0x7F,0x00,0x3F,0x00,0x60,0x00,0xC0,0x00,0xC0,0x60,0xE0,0xE0,0x7F,0xC0,0x3F,0x80,0x00,0x00,0x00,0x00},        // 0x33
  {0x38,0x00,0x3C,0x00,0x3E,0x00,0x37,0x00,0x33,0x80,0x31,0xC0,0x30,0xE0,0x30,0x60,0xFF,0xE0,0xFF,0xE0,0x30,0x00,0x30,0x00,0x30,0x00,0x30,0x00,0x00,0x00,0x00,0x00},        // 0x34
  {0xFF,0xE0,0xFF,0xE0,0x00,0x60,0x00,0x60,0x00,0x60,0x3F,0xE0,0x7F,0xC0,0xE0,0x00,0xC0,0x00,0xC0,0x00,0xC0,0x60,0xE0,0xE0,0x7F,0xC0,0x3F,0x80,0x00,0x00,0x00,0x00},        // 0x35
  {0x3C,0x00,0x3E,0x00,0x07,0x00,0x03,0x80,0x01,0xC0,0x00,0xC0,0x3F,0xE0,0x7F,0xE0,0xE0,0xE0,0xC0,0x60,0xC0,0x60,0xE0,0xE0,0x7F,0xC0,0x3F,0x80,0x00,0x00,0x00,0x00},        // 0x36
  {0xFF,0xE0,0xFF,0xE0,0x60,0x00,0x60,0x00,0x30,0x00,0x30,0x00,0x18,0x00,0x18,0x00,0x0C,0x00,0x0C,0x00,0x06,0x00,0x06,0x00,0x03,0x00,0x03,0x00,0x00,0x00,0x00,0x00},        // 0x37
  {0x1F,0x00,0x3F,0x80,0x71,0xC0,0x60,0xC0,0x60,0xC0,0x71,0xC0,0x3F,0x80,0x7F,0xC0,0xE0,0xE0,0xC0,0x60,0xC0,0x60,0xE0,0xE0,0x7F,0xC0,0x3F,0x80,0x00,0x00,0x00,0x00},        // 0x38
  {0x3F,0x80,0x7F,0xC0,0xE0,0xE0,0xC0,0x60,0xC0,0x60,0xE0,0xE0,0xFF,0xC0,0xFF,0x80,0x60,0x00,0x70,0x00,0x38,0x00,0x1C,0x00,0x0F,0x80,0x07,0x80,0x00,0x00,0x00,0x00},        // 0x39
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x07,0x00,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x07,0x00,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x3A
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x07,0x00,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x07,0x00,0x07,0x00,0x06,0x00,0x06,0x00,0x03,0x00},        // 0x3B
  {0x30,0x00,0x38,0x00,0x1C,0x00,0x0E,0x00,0x07,0x00,0x03,0x80,0x01,0xC0,0x01,0xC0,0x03,0x80,0x07,0x00,0x0E,0x00,0x1C,0x00,0x38,0x00,0x30,0x00,0x00,0x00,0x00,0x00},        // 0x3C
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7F,0xC0,0x7F,0xC0,0x00,0x00,0x00,0x00,0x7F,0xC0,0x7F,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x3D
  {0x00,0xC0,0x01,0xC0,0x03,0x80,0x07,0x00,0x0E,0x00,0x1C,0x00,0x38,0x00,0x38,0x00,0x1C,0x00,0x0E,0x00,0x07,0x00,0x03,0x80,0x01,0xC0,0x00,0xC0,0x00,0x00,0x00,0x00},        // 0x3E
  {0x1F,0x80,0x3F,0xC0,0x70,0xE0,0x60,0x60,0x70,0x60,0x38,0x00,0x1C,0x00,0x0E,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x00,0x00,0x06,0x00,0x06,0x00,0x00,0x00,0x00,0x00},        // 0x3F
  {0x3F,0x80,0x7F,0xC0,0x60,0xC0,0xDE,0x60,0xDF,0x60,0xDB,0x60,0xDB,0x60,0xDB,0x60,0xDB,0x60,0x7F,0x60,0x3E,0x60,0x00,0xE0,0x3F,0xC0,0x3F,0x00,0x00,0x00,0x00,0x00},        // 0x40
  {0x06,0x00,0x06,0x00,0x0F,0x00,0x0F,0x00,0x0F,0x00,0x19,0x80,0x19,0x80,0x19,0x80,0x30,0xC0,0x3F,0xC0,0x3F,0xC0,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,0x00,0x00},        // 0x41
  {0x0F,0xE0,0x1F,0xE0,0x38,0x60,0x30,0x60,0x30,0x60,0x38,0x60,0x1F,0xE0,0x3F,0xE0,0x70,0x60,0x60,0x60,0x60,0x60,0x70,0x60,0x3F,0xE0,0x1F,0xE0,0x00,0x00,0x00,0x00},        // 0x42
  {0x1F,0x00,0x3F,0x80,0x71,0xC0,0x60,0xC0,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x60,0xC0,0x71,0xC0,0x3F,0x80,0x1F,0x00,0x00,0x00,0x00,0x00},        // 0x43
  {0x0F,0xE0,0x1F,0xE0,0x38,0x60,0x30,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x30,0x60,0x38,0x60,0x1F,0xE0,0x0F,0xE0,0x00,0x00,0x00,0x00},        // 0x44
  {0x7F,0xE0,0x7F,0xE0,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x1F,0xE0,0x1F,0xE0,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x7F,0xE0,0x7F,0xE0,0x00,0x00,0x00,0x00},        // 0x45
  {0x7F,0xE0,0x7F,0xE0,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x1F,0xE0,0x1F,0xE0,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x00,0x00,0x00},        // 0x46
  {0x3F,0x00,0x7F,0x80,0x61,0xC0,0x00,0xC0,0x00,0x60,0x00,0x60,0x7C,0x60,0x7C,0x60,0x60,0x60,0x60,0x60,0x60,0xC0,0x61,0xC0,0x7F,0x80,0x7F,0x00,0x00,0x00,0x00,0x00},        // 0x47
  {0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x7F,0xE0,0x7F,0xE0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,0x00,0x00},        // 0x48
  {0x1F,0x80,0x1F,0x80,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x1F,0x80,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x49
  {0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x60,0x60,0x60,0x30,0xE0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x4A
  {0x60,0x60,0x70,0x60,0x38,0x60,0x1C,0x60,0x0E,0x60,0x07,0x60,0x03,0xE0,0x03,0xE0,0x07,0x60,0x0E,0x60,0x1C,0x60,0x38,0x60,0x70,0x60,0x60,0x60,0x00,0x00,0x00,0x00},        // 0x4B
  {0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x7F,0xE0,0x7F,0xE0,0x00,0x00,0x00,0x00},        // 0x4C
  {0x60,0x60,0x70,0xE0,0x70,0xE0,0x79,0xE0,0x79,0xE0,0x6F,0x60,0x6F,0x60,0x66,0x60,0x66,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,0x00,0x00},        // 0x4D
  {0x60,0x60,0x60,0xE0,0x60,0xE0,0x61,0xE0,0x63,0x60,0x63,0x60,0x66,0x60,0x66,0x60,0x6C,0x60,0x6C,0x60,0x78,0x60,0x70,0x60,0x70,0x60,0x60,0x60,0x00,0x00,0x00,0x00},        // 0x4E
  {0x0F,0x00,0x1F,0x80,0x39,0xC0,0x30,0xC0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x30,0xC0,0x39,0xC0,0x1F,0x80,0x0F,0x00,0x00,0x00,0x00,0x00},        // 0x4F
  {0x1F,0xE0,0x3F,0xE0,0x70,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0x60,0x3F,0xE0,0x1F,0xE0,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x00,0x00,0x00},        // 0x50
  {0x0F,0x00,0x1F,0x80,0x39,0xC0,0x30,0xC0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x6C,0x60,0x3C,0xC0,0x39,0xC0,0x7F,0x80,0x6F,0x00,0x00,0x00,0x00,0x00},        // 0x51
  {0x1F,0xE0,0x3F,0xE0,0x70,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0x60,0x3F,0xE0,0x1F,0xE0,0x0E,0x60,0x1C,0x60,0x38,0x60,0x70,0x60,0x60,0x60,0x00,0x00,0x00,0x00},        // 0x52
  {0x1F,0x80,0x3F,0xC0,0x70,0xE0,0x60,0x60,0x00,0x60,0x00,0xE0,0x1F,0xC0,0x3F,0x80,0x70,0x00,0x60,0x00,0x60,0x60,0x70,0xE0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x53
  {0x3F,0xC0,0x3F,0xC0,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x00,0x00,0x00,0x00},        // 0x54
  {0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x30,0xC0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x55
  {0x60,0x60,0x60,0x60,0x60,0x60,0x30,0xC0,0x30,0xC0,0x30,0xC0,0x19,0x80,0x19,0x80,0x19,0x80,0x0F,0x00,0x0F,0x00,0x0F,0x00,0x06,0x00,0x06,0x00,0x00,0x00,0x00,0x00},        // 0x56
  {0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x66,0x60,0x66,0x60,0x6F,0x60,0x79,0xE0,0x70,0xE0,0x70,0xE0,0x60,0x60,0x00,0x00,0x00,0x00},        // 0x57
  {0x60,0x60,0x60,0x60,0x30,0xC0,0x30,0xC0,0x19,0x80,0x0F,0x00,0x06,0x00,0x06,0x00,0x0F,0x00,0x19,0x80,0x30,0xC0,0x30,0xC0,0x60,0x60,0x60,0x60,0x00,0x00,0x00,0x00},        // 0x58
  {0x60,0x60,0x60,0x60,0x30,0xC0,0x30,0xC0,0x19,0x80,0x19,0x80,0x0F,0x00,0x0F,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x00,0x00,0x00,0x00},        // 0x59
  {0x7F,0xE0,0x7F,0xE0,0x30,0x00,0x30,0x00,0x18,0x00,0x0C,0x00,0x06,0x00,0x06,0x00,0x03,0x00,0x01,0x80,0x00,0xC0,0x00,0xC0,0x7F,0xE0,0x7F,0xE0,0x00,0x00,0x00,0x00},        // 0x5A
  {0x1F,0x80,0x1F,0x80,0x01,0x80,0x01,0x80,0x01,0x80,0x01,0x80,0x01,0x80,0x01,0x80,0x01,0x80,0x01,0x80,0x01,0x80,0x01,0x80,0x1F,0x80,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x5B
  {0x00,0x00,0x00,0x20,0x00,0x60,0x00,0xE0,0x01,0xC0,0x03,0x80,0x07,0x00,0x0E,0x00,0x1C,0x00,0x38,0x00,0x70,0x00,0xE0,0x00,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x5C
  {0x1F,0x80,0x1F,0x80,0x18,0x00,0x18,0x00,0x18,0x00,0x18,0x00,0x18,0x00,0x18,0x00,0x18,0x00,0x18,0x00,0x18,0x00,0x18,0x00,0x1F,0x80,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x5D
  {0x04,0x00,0x0E,0x00,0x1F,0x00,0x3B,0x80,0x71,0xC0,0xE0,0xE0,0xC0,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x5E
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xE0,0xFF,0xE0},        // 0x5F
  {0x00,0x00,0x0E,0x00,0x0E,0x00,0x0E,0x00,0x06,0x00,0x06,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x60
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x80,0x7F,0xC0,0x60,0x00,0x7F,0x80,0x7F,0xC0,0x60,0x60,0x60,0x60,0x7F,0xE0,0x7F,0xC0,0x00,0x00,0x00,0x00},        // 0x61
  {0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x1F,0x60,0x3F,0xE0,0x70,0xE0,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0x60,0x3F,0xE0,0x1F,0xE0,0x00,0x00,0x00,0x00},        // 0x62
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0x80,0x3F,0xC0,0x60,0xE0,0x00,0x60,0x00,0x60,0x00,0x60,0x60,0xE0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x63
  {0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x6F,0x80,0x7F,0xC0,0x78,0xE0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xE0,0x7F,0xC0,0x7F,0x80,0x00,0x00,0x00,0x00},        // 0x64
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0x80,0x3F,0xC0,0x60,0xE0,0x7F,0xE0,0x3F,0xE0,0x00,0x60,0x00,0xE0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x65
  {0x1E,0x00,0x1F,0x00,0x03,0x80,0x01,0x80,0x01,0x80,0x01,0x80,0x0F,0xE0,0x0F,0xE0,0x01,0x80,0x01,0x80,0x01,0x80,0x01,0x80,0x01,0x80,0x01,0x80,0x00,0x00,0x00,0x00},        // 0x66
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7F,0x80,0x7F,0xC0,0x60,0xE0,0x60,0x60,0x70,0xE0,0x7F,0xC0,0x6F,0x80,0x60,0x00,0x70,0x00,0x3F,0xC0,0x1F,0xC0},        // 0x67
  {0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x0F,0x60,0x1F,0xE0,0x38,0xE0,0x30,0x60,0x30,0x60,0x30,0x60,0x30,0x60,0x30,0x60,0x30,0x60,0x00,0x00,0x00,0x00},        // 0x68
  {0x00,0x00,0x00,0x00,0x06,0x00,0x06,0x00,0x00,0x00,0x07,0x00,0x07,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x1F,0x80,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x69
  {0x00,0x00,0x00,0x00,0x18,0x00,0x18,0x00,0x00,0x00,0x1C,0x00,0x1C,0x00,0x18,0x00,0x18,0x00,0x18,0x00,0x18,0x00,0x18,0x00,0x18,0x00,0x19,0x80,0x1F,0x80,0x0F,0x00},        // 0x6A
  {0x00,0xC0,0x00,0xC0,0x00,0xC0,0x00,0xC0,0x00,0xC0,0x18,0xC0,0x1C,0xC0,0x0E,0xC0,0x07,0xC0,0x07,0xC0,0x0E,0xC0,0x1C,0xC0,0x38,0xC0,0x30,0xC0,0x00,0x00,0x00,0x00},        // 0x6B
  {0x07,0x00,0x07,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x1F,0x80,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x6C
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x19,0xA0,0x3F,0xE0,0x7F,0xE0,0x66,0x60,0x66,0x60,0x66,0x60,0x66,0x60,0x66,0x60,0x66,0x60,0x00,0x00,0x00,0x00},        // 0x6D
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0xC0,0x3F,0xC0,0x70,0xC0,0x60,0xC0,0x60,0xC0,0x60,0xC0,0x60,0xC0,0x60,0xC0,0x60,0xC0,0x00,0x00,0x00,0x00},        // 0x6E
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0x80,0x3F,0xC0,0x70,0xE0,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0xE0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x6F
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0xE0,0x3F,0xE0,0x70,0x60,0x60,0x60,0x60,0x60,0x70,0xE0,0x3F,0xE0,0x1F,0x60,0x00,0x60,0x00,0x60,0x00,0x60},        // 0x70
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7F,0x80,0x7F,0xC0,0x60,0xE0,0x60,0x60,0x60,0x60,0x70,0xE0,0x7F,0xC0,0x6F,0x80,0x60,0x00,0x60,0x00,0x60,0x00},        // 0x71
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3E,0xC0,0x7F,0xC0,0x61,0xC0,0x00,0xC0,0x00,0xC0,0x00,0xC0,0x00,0xC0,0x00,0xC0,0x00,0xC0,0x00,0x00,0x00,0x00},        // 0x72
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0xC0,0x1F,0xE0,0x00,0x60,0x0F,0xE0,0x1F,0xC0,0x18,0x00,0x18,0x00,0x1F,0xE0,0x0F,0xC0,0x00,0x00,0x00,0x00},        // 0x73
  {0x00,0x00,0x01,0x80,0x01,0x80,0x01,0x80,0x01,0x80,0x0F,0xE0,0x0F,0xE0,0x01,0x80,0x01,0x80,0x01,0x80,0x01,0x80,0x01,0x80,0x1F,0x80,0x1F,0x00,0x00,0x00,0x00,0x00},        // 0x74
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0xE0,0x7F,0xC0,0x6F,0x80,0x00,0x00,0x00,0x00},        // 0x75
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x60,0x60,0x60,0x30,0xC0,0x30,0xC0,0x19,0x80,0x19,0x80,0x0F,0x00,0x0F,0x00,0x06,0x00,0x00,0x00,0x00,0x00},        // 0x76
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x60,0x66,0x60,0x66,0x60,0x66,0x60,0x66,0x60,0x6F,0x60,0x3F,0xC0,0x39,0xC0,0x10,0x80,0x00,0x00,0x00,0x00},        // 0x77
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x60,0x38,0xE0,0x1D,0xC0,0x0F,0x80,0x07,0x00,0x0F,0x80,0x1D,0xC0,0x38,0xE0,0x30,0x60,0x00,0x00,0x00,0x00},        // 0x78
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0xC0,0x30,0xC0,0x19,0x80,0x19,0x80,0x0F,0x00,0x0F,0x00,0x06,0x00,0x06,0x00,0x03,0x00,0x03,0x00,0x01,0x80},        // 0x79
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0xE0,0x1F,0xE0,0x0C,0x00,0x06,0x00,0x03,0x00,0x01,0x80,0x00,0xC0,0x3F,0xE0,0x3F,0xE0,0x00,0x00,0x00,0x00},        // 0x7A
  {0x3C,0x00,0x3E,0x00,0x07,0x00,0x03,0x00,0x03,0x00,0x03,0x00,0x03,0x80,0x01,0xC0,0x03,0x80,0x03,0x00,0x03,0x00,0x03,0x00,0x07,0x00,0x3E,0x00,0x3C,0x00,0x00,0x00},        // 0x7B
  {0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x00,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x00,0x00,0x00,0x00},        // 0x7C
  {0x03,0xC0,0x07,0xC0,0x0E,0x00,0x0C,0x00,0x0C,0x00,0x0C,0x00,0x1C,0x00,0x38,0x00,0x1C,0x00,0x0C,0x00,0x0C,0x00,0x0C,0x00,0x0E,0x00,0x07,0xC0,0x03,0xC0,0x00,0x00},        // 0x7D
  {0x00,0x00,0x00,0x00,0x63,0x80,0x36,0xC0,0x1C,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x7E
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x0F,0x00,0x19,0x80,0x30,0xC0,0x60,0x60,0x60,0x60,0x7F,0xE0,0x7F,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x7F
  {0x1F,0x00,0x3F,0x80,0x71,0xC0,0x60,0xC0,0x60,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x60,0xC0,0x71,0xC0,0x3F,0x80,0x1F,0x00,0x06,0x00,0x07,0x80,0x07,0x80},        // 0x80
  {0x00,0x00,0x00,0x00,0x19,0x80,0x19,0x80,0x00,0x00,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0xE0,0x7F,0xC0,0x6F,0x80,0x00,0x00,0x00,0x00},        // 0x81
  {0x00,0x00,0x18,0x00,0x0C,0x00,0x06,0x00,0x00,0x00,0x1F,0x80,0x3F,0xC0,0x60,0xE0,0x7F,0xE0,0x7F,0xE0,0x00,0x60,0x00,0xE0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x82
  {0x00,0x00,0x06,0x00,0x0F,0x00,0x19,0x80,0x00,0x00,0x3F,0x80,0x7F,0xC0,0x60,0x00,0x7F,0x80,0x7F,0xC0,0x60,0x60,0x60,0x60,0x7F,0xE0,0x7F,0xC0,0x00,0x00,0x00,0x00},        // 0x83
  {0x00,0x00,0x00,0x00,0x19,0x80,0x19,0x80,0x00,0x00,0x3F,0x80,0x7F,0xC0,0x60,0x00,0x7F,0x80,0x7F,0xC0,0x60,0x60,0x60,0x60,0x7F,0xE0,0x7F,0xC0,0x00,0x00,0x00,0x00},        // 0x84
  {0x00,0x00,0x03,0x00,0x06,0x00,0x0C,0x00,0x00,0x00,0x3F,0x80,0x7F,0xC0,0x60,0x00,0x7F,0x80,0x7F,0xC0,0x60,0x60,0x60,0x60,0x7F,0xE0,0x7F,0xC0,0x00,0x00,0x00,0x00},        // 0x85
  {0x00,0x00,0x06,0x00,0x09,0x00,0x06,0x00,0x00,0x00,0x3F,0x80,0x7F,0xC0,0x60,0x00,0x7F,0x80,0x7F,0xC0,0x60,0x60,0x60,0x60,0x7F,0xE0,0x7F,0xC0,0x00,0x00,0x00,0x00},        // 0x86
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0x80,0x3F,0xC0,0x70,0xE0,0x00,0x60,0x00,0x60,0x00,0x60,0x70,0xE0,0x3F,0xC0,0x1F,0x80,0x06,0x00,0x07,0x80},        // 0x87
  {0x00,0x00,0x06,0x00,0x0F,0x00,0x19,0x80,0x00,0x00,0x1F,0x80,0x3F,0xC0,0x60,0xE0,0x7F,0xE0,0x7F,0xE0,0x00,0x60,0x00,0x60,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x88
  {0x00,0x00,0x00,0x00,0x19,0x80,0x19,0x80,0x00,0x00,0x1F,0x80,0x3F,0xC0,0x60,0xE0,0x7F,0xE0,0x7F,0xE0,0x00,0x60,0x00,0x60,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x89
  {0x00,0x00,0x03,0x00,0x06,0x00,0x0C,0x00,0x00,0x00,0x1F,0x80,0x3F,0xC0,0x60,0xE0,0x7F,0xE0,0x7F,0xE0,0x00,0x60,0x00,0x60,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x8A
  {0x00,0x00,0x00,0x00,0x0D,0x80,0x0D,0x80,0x00,0x00,0x07,0x00,0x07,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x1F,0x80,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x8B
  {0x00,0x00,0x06,0x00,0x0F,0x00,0x19,0x80,0x00,0x00,0x07,0x00,0x07,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x1F,0x80,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x8C
  {0x00,0x00,0x03,0x00,0x06,0x00,0x0C,0x00,0x00,0x00,0x07,0x00,0x07,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x1F,0x80,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x8D
  {0x19,0x80,0x19,0x80,0x00,0x00,0x06,0x00,0x06,0x00,0x0F,0x00,0x0F,0x00,0x19,0x80,0x19,0x80,0x30,0xC0,0x3F,0xC0,0x7F,0xE0,0x60,0x60,0x60,0x60,0x00,0x00,0x00,0x00},        // 0x8E
  {0x06,0x00,0x09,0x00,0x06,0x00,0x00,0x00,0x06,0x00,0x0F,0x00,0x0F,0x00,0x19,0x80,0x19,0x80,0x30,0xC0,0x3F,0xC0,0x7F,0xE0,0x60,0x60,0x60,0x60,0x00,0x00,0x00,0x00},        // 0x8F
  {0x18,0x00,0x0C,0x00,0x06,0x00,0x7F,0xE0,0x7F,0xE0,0x00,0x60,0x00,0x60,0x1F,0xE0,0x1F,0xE0,0x00,0x60,0x00,0x60,0x00,0x60,0x7F,0xE0,0x7F,0xE0,0x00,0x00,0x00,0x00},        // 0x90
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3B,0xC0,0x66,0x60,0x66,0x00,0x3F,0xC0,0x06,0x60,0x06,0x60,0x66,0x60,0x3D,0xC0,0x00,0x00,0x00,0x00},        // 0x91
  {0x7E,0x00,0x7E,0x00,0x0F,0x00,0x0F,0x00,0x0F,0x80,0x0D,0x80,0x3D,0x80,0x3C,0xC0,0x0C,0xC0,0x0F,0xC0,0x0F,0xE0,0x0C,0x60,0x7C,0x60,0x7C,0x60,0x00,0x00,0x00,0x00},        // 0x92
  {0x00,0x00,0x06,0x00,0x0F,0x00,0x19,0x80,0x00,0x00,0x1F,0x80,0x3F,0xC0,0x70,0xE0,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0xE0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x93
  {0x00,0x00,0x00,0x00,0x19,0x80,0x19,0x80,0x00,0x00,0x1F,0x80,0x3F,0xC0,0x70,0xE0,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0xE0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x94
  {0x00,0x00,0x03,0x00,0x06,0x00,0x0C,0x00,0x00,0x00,0x1F,0x80,0x3F,0xC0,0x70,0xE0,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0xE0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x95
  {0x00,0x00,0x06,0x00,0x0F,0x00,0x19,0x80,0x00,0x00,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0xE0,0x7F,0xC0,0x6F,0x80,0x00,0x00,0x00,0x00},        // 0x96
  {0x00,0x00,0x03,0x00,0x06,0x00,0x0C,0x00,0x00,0x00,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0xE0,0x7F,0xC0,0x6F,0x80,0x00,0x00,0x00,0x00},        // 0x97
  {0x00,0x00,0x00,0x00,0x19,0x80,0x19,0x80,0x00,0x00,0x30,0xC0,0x30,0xC0,0x19,0x80,0x19,0x80,0x0F,0x00,0x0F,0x00,0x06,0x00,0x06,0x00,0x03,0x00,0x03,0x00,0x01,0x80},        // 0x98
  {0x19,0x80,0x19,0x80,0x00,0x00,0x1F,0x80,0x3F,0xC0,0x70,0xE0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0xE0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0x99
  {0x00,0x00,0x00,0x00,0x19,0x80,0x19,0x80,0x00,0x00,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0xE0,0x7F,0xC0,0x6F,0x80,0x00,0x00,0x00,0x00},        // 0x9A
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x6F,0x80,0x3F,0xC0,0x78,0xE0,0x6C,0x60,0x66,0x60,0x63,0x60,0x71,0xE0,0x3F,0xC0,0x1F,0x60,0x00,0x00,0x00,0x00},        // 0x9B
  {0x00,0x00,0x00,0x00,0x1E,0x00,0x3F,0x00,0x33,0x00,0x03,0x00,0x03,0x00,0x0F,0x80,0x03,0x00,0x03,0x00,0x01,0x80,0x7F,0xC0,0x3D,0xC0,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x9C
  {0x00,0x00,0x00,0x00,0x6F,0x80,0x3F,0xC0,0x78,0xE0,0x6C,0x60,0x6C,0x60,0x66,0x60,0x66,0x60,0x63,0x60,0x63,0x60,0x71,0xE0,0x3F,0xC0,0x1F,0x60,0x00,0x00,0x00,0x00},        // 0x9D
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0xC0,0x19,0x80,0x0F,0x00,0x06,0x00,0x0F,0x00,0x19,0x80,0x30,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0x9E
  {0x1C,0x00,0x3E,0x00,0x36,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x1F,0x80,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0xC0,0x07,0xC0,0x03,0x80,0x00,0x00},        // 0x9F
  {0x00,0x00,0x0C,0x00,0x06,0x00,0x03,0x00,0x00,0x00,0x3F,0x80,0x7F,0xC0,0x60,0x00,0x7F,0x80,0x7F,0xC0,0x60,0x60,0x60,0x60,0x7F,0xE0,0x7F,0xC0,0x00,0x00,0x00,0x00},        // 0xA0
  {0x00,0x00,0x0C,0x00,0x06,0x00,0x03,0x00,0x00,0x00,0x07,0x00,0x07,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x1F,0x80,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0xA1
  {0x00,0x00,0x0C,0x00,0x06,0x00,0x03,0x00,0x00,0x00,0x1F,0x80,0x3F,0xC0,0x70,0xE0,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0xE0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0xA2
  {0x00,0x00,0x0C,0x00,0x06,0x00,0x03,0x00,0x00,0x00,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0xE0,0x7F,0xC0,0x6F,0x80,0x00,0x00,0x00,0x00},        // 0xA3
  {0x00,0x00,0x00,0x00,0x37,0x00,0x1D,0x80,0x00,0x00,0x1F,0xC0,0x3F,0xC0,0x70,0xC0,0x60,0xC0,0x60,0xC0,0x60,0xC0,0x60,0xC0,0x60,0xC0,0x60,0xC0,0x00,0x00,0x00,0x00},        // 0xA4
  {0x37,0x00,0x1D,0x80,0x00,0x00,0x60,0x60,0x60,0xE0,0x61,0xE0,0x63,0xE0,0x67,0x60,0x6E,0x60,0x7C,0x60,0x78,0x60,0x70,0x60,0x60,0x60,0x60,0x60,0x00,0x00,0x00,0x00},        // 0xA5
  {0x3F,0x80,0x7F,0xC0,0x60,0x00,0x7F,0xC0,0x7F,0xE0,0x60,0x60,0x7F,0xE0,0x7F,0xC0,0x00,0x00,0x3F,0xC0,0x3F,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xA6
  {0x1F,0x80,0x3F,0xC0,0x70,0xE0,0x60,0x60,0x60,0x60,0x70,0xE0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x3F,0xC0,0x3F,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xA7
  {0x06,0x00,0x06,0x00,0x00,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x07,0x00,0x03,0x80,0x01,0xC0,0x60,0xE0,0x60,0x60,0x70,0xE0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0xA8
  {0x00,0x00,0x00,0x00,0x3F,0x80,0x7F,0xC0,0xE0,0xE0,0xCF,0x60,0xDB,0x60,0xCF,0x60,0xDB,0x60,0xDB,0x60,0xE0,0xE0,0x7F,0xC0,0x3F,0x80,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xA9
  {0x00,0x00,0x00,0x00,0x00,0x00,0x7F,0xF0,0x7F,0xF0,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xAA
  {0x00,0x00,0x00,0x00,0x00,0xC0,0x00,0xE0,0x30,0xC0,0x18,0xC0,0x0D,0xE0,0x06,0x00,0x3B,0x00,0x61,0x80,0x30,0xC0,0x18,0x00,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xAB
  {0x00,0x00,0x00,0x00,0x00,0xC0,0x00,0xE0,0x30,0xC0,0x18,0xC0,0x0D,0xE0,0x06,0x00,0x6B,0x00,0x6D,0x80,0x7C,0xC0,0x60,0x00,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xAC
  {0x06,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x0F,0x00,0x0F,0x00,0x0F,0x00,0x0F,0x00,0x0F,0x00,0x06,0x00,0x06,0x00,0x00,0x00,0x00,0x00},        // 0xAD
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x31,0x80,0x18,0xC0,0x0C,0x60,0x18,0xC0,0x31,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xAE
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0C,0x60,0x18,0xC0,0x31,0x80,0x18,0xC0,0x0C,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xAF
  {0x11,0x10,0x44,0x40,0x11,0x10,0x44,0x40,0x11,0x10,0x44,0x40,0x11,0x10,0x44,0x40,0x11,0x10,0x44,0x40,0x11,0x10,0x44,0x40,0x11,0x10,0x44,0x40,0x11,0x10,0x44,0x40},        // 0xB0
  {0xAA,0xA0,0x55,0x50,0xAA,0xA0,0x55,0x50,0xAA,0xA0,0x55,0x50,0xAA,0xA0,0x55,0x50,0xAA,0xA0,0x55,0x50,0xAA,0xA0,0x55,0x50,0xAA,0xA0,0x55,0x50,0xAA,0xA0,0x55,0x50},        // 0xB1
  {0xEE,0xE0,0xBB,0xB0,0xEE,0xE0,0xBB,0xB0,0xEE,0xE0,0xBB,0xB0,0xEE,0xE0,0xBB,0xB0,0xEE,0xE0,0xBB,0xB0,0xEE,0xE0,0xBB,0xB0,0xEE,0xE0,0xBB,0xB0,0xEE,0xE0,0xBB,0xB0},        // 0xB2
  {0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00},        // 0xB3
  {0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x07,0xF0,0x07,0xF0,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00},        // 0xB4
  {0x0C,0x00,0x06,0x00,0x03,0x00,0x06,0x00,0x06,0x00,0x0F,0x00,0x0F,0x00,0x19,0x80,0x19,0x80,0x30,0xC0,0x3F,0xC0,0x7F,0xE0,0x60,0x60,0x60,0x60,0x00,0x00,0x00,0x00},        // 0xB5
  {0x06,0x00,0x0F,0x00,0x19,0x80,0x06,0x00,0x06,0x00,0x0F,0x00,0x0F,0x00,0x19,0x80,0x19,0x80,0x30,0xC0,0x3F,0xC0,0x7F,0xE0,0x60,0x60,0x60,0x60,0x00,0x00,0x00,0x00},        // 0xB6
  {0x03,0x00,0x06,0x00,0x0C,0x00,0x06,0x00,0x06,0x00,0x0F,0x00,0x0F,0x00,0x19,0x80,0x19,0x80,0x30,0xC0,0x3F,0xC0,0x7F,0xE0,0x60,0x60,0x60,0x60,0x00,0x00,0x00,0x00},        // 0xB7
  {0x00,0x00,0x00,0x00,0x3F,0x80,0x7F,0xC0,0xE0,0xE0,0xCE,0x60,0xDB,0x60,0xC3,0x60,0xDB,0x60,0xCE,0x60,0xE0,0xE0,0x7F,0xC0,0x3F,0x80,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xB8
  {0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xF0,0x06,0xF0,0x06,0x00,0x06,0xF0,0x06,0xF0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0},        // 0xB9
  {0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0},        // 0xBA
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xF0,0x07,0xF0,0x06,0x00,0x06,0xF0,0x06,0xF0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0},        // 0xBB
  {0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xF0,0x06,0xF0,0x06,0x00,0x07,0xF0,0x07,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xBC
  {0x00,0x00,0x06,0x00,0x06,0x00,0x1F,0x00,0x3F,0x80,0x37,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x37,0xC0,0x3F,0x80,0x1F,0x00,0x06,0x00,0x06,0x00,0x00,0x00,0x00,0x00},        // 0xBD
  {0x60,0x60,0x60,0x60,0x30,0xC0,0x30,0xC0,0x19,0x80,0x19,0x80,0x0F,0x00,0x0F,0x00,0x06,0x00,0x3F,0xC0,0x06,0x00,0x3F,0xC0,0x06,0x00,0x06,0x00,0x00,0x00,0x00,0x00},        // 0xBE
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xF0,0x07,0xF0,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00},        // 0xBF
  {0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0xFE,0x00,0xFE,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xC0
  {0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0xFF,0xF0,0xFF,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xC1
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xF0,0xFF,0xF0,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00},        // 0xC2
  {0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0xFE,0x00,0xFE,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00},        // 0xC3
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xF0,0xFF,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xC4
  {0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0xFF,0xF0,0xFF,0xF0,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00},        // 0xC5
  {0x00,0x00,0x00,0x00,0x37,0x00,0x1D,0x80,0x00,0x00,0x3F,0x80,0x7F,0xC0,0x60,0x00,0x7F,0x80,0x7F,0xC0,0x60,0x60,0x60,0x60,0x7F,0xE0,0x7F,0xC0,0x00,0x00,0x00,0x00},        // 0xC6
  {0x37,0x00,0x1D,0x80,0x00,0x00,0x06,0x00,0x06,0x00,0x0F,0x00,0x0F,0x00,0x19,0x80,0x19,0x80,0x30,0xC0,0x3F,0xC0,0x7F,0xE0,0x60,0x60,0x60,0x60,0x00,0x00,0x00,0x00},        // 0xC7
  {0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0xFE,0xC0,0xFE,0xC0,0x00,0xC0,0xFF,0xC0,0xFF,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xC8
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xC0,0xFF,0xC0,0x00,0xC0,0xFE,0xC0,0xFE,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0},        // 0xC9
  {0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0xFE,0xF0,0xFE,0xF0,0x00,0x00,0xFF,0xF0,0xFF,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xCA
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xF0,0xFF,0xF0,0x00,0x00,0xFE,0xF0,0xFE,0xF0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0},        // 0xCB
  {0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0xFE,0xC0,0xFE,0xC0,0x00,0xC0,0xFE,0xC0,0xFE,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0},        // 0xCC
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xF0,0xFF,0xF0,0x00,0x00,0xFF,0xF0,0xFF,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xCD
  {0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0xFE,0xF0,0xFE,0xF0,0x00,0x00,0xFE,0xF0,0xFE,0xF0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0,0x06,0xC0},        // 0xCE
  {0x00,0x00,0x60,0x60,0x6F,0x60,0x3F,0xC0,0x70,0xE0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0xE0,0x3F,0xC0,0x6F,0x60,0x60,0x60,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xCF
  {0x00,0x00,0x00,0x00,0x0F,0x00,0x1F,0x80,0x11,0x80,0x01,0x80,0x03,0x80,0x07,0x00,0x0E,0x00,0x1F,0x00,0x19,0x80,0x19,0x80,0x1F,0x80,0x0F,0x00,0x00,0x00,0x00,0x00},        // 0xD0
  {0x0F,0xC0,0x1F,0xC0,0x38,0xC0,0x30,0xC0,0x60,0xC0,0x60,0xC0,0x61,0xE0,0x61,0xE0,0x60,0xC0,0x60,0xC0,0x30,0xC0,0x38,0xC0,0x1F,0xC0,0x0F,0xC0,0x00,0x00,0x00,0x00},        // 0xD1
  {0x06,0x00,0x0F,0x00,0x19,0x80,0x7F,0xE0,0x7F,0xE0,0x00,0x60,0x00,0x60,0x1F,0xE0,0x1F,0xE0,0x00,0x60,0x00,0x60,0x00,0x60,0x7F,0xE0,0x7F,0xE0,0x00,0x00,0x00,0x00},        // 0xD2
  {0x19,0x80,0x19,0x80,0x00,0x00,0x7F,0xE0,0x7F,0xE0,0x00,0x60,0x00,0x60,0x1F,0xE0,0x1F,0xE0,0x00,0x60,0x00,0x60,0x00,0x60,0x7F,0xE0,0x7F,0xE0,0x00,0x00,0x00,0x00},        // 0xD3
  {0x01,0x80,0x03,0x00,0x06,0x00,0x7F,0xE0,0x7F,0xE0,0x00,0x60,0x00,0x60,0x1F,0xE0,0x1F,0xE0,0x00,0x60,0x00,0x60,0x00,0x60,0x7F,0xE0,0x7F,0xE0,0x00,0x00,0x00,0x00},        // 0xD4
  {0x00,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xD5
  {0x18,0x00,0x0C,0x00,0x06,0x00,0x1F,0x80,0x1F,0x80,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x1F,0x80,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0xD6
  {0x06,0x00,0x0F,0x00,0x19,0x80,0x1F,0x80,0x1F,0x80,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x1F,0x80,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0xD7
  {0x19,0x80,0x19,0x80,0x00,0x00,0x1F,0x80,0x1F,0x80,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x1F,0x80,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0xD8
  {0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x07,0xF0,0x07,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xD9
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFE,0x00,0xFE,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00},        // 0xDA
  {0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0},        // 0xDB
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0},        // 0xDC
  {0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x00,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x00,0x00,0x00,0x00},        // 0xDD
  {0x01,0x80,0x03,0x00,0x06,0x00,0x1F,0x80,0x1F,0x80,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x1F,0x80,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0xDE
  {0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0xFF,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xDF
  {0x18,0x00,0x0C,0x00,0x06,0x00,0x1F,0x80,0x3F,0xC0,0x70,0xE0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0xE0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0xE0
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0x00,0x19,0x80,0x30,0xC0,0x30,0xC0,0x1F,0xC0,0x38,0xC0,0x30,0xC0,0x30,0xC0,0x38,0xC0,0x1F,0xC0,0x00,0xC0,0x00,0xC0},        // 0xE1
  {0x06,0x00,0x0F,0x00,0x19,0x80,0x1F,0x80,0x3F,0xC0,0x70,0xE0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0xE0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0xE2
  {0x01,0x80,0x03,0x00,0x06,0x00,0x1F,0x80,0x3F,0xC0,0x70,0xE0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0xE0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0xE3
  {0x00,0x00,0x00,0x00,0x1B,0x80,0x0E,0xC0,0x00,0x00,0x1F,0x80,0x3F,0xC0,0x70,0xE0,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0xE0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0xE4
  {0x37,0x00,0x1D,0x80,0x00,0x00,0x1F,0x80,0x3F,0xC0,0x70,0xE0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0xE0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0xE5
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x60,0x30,0x60,0x30,0x60,0x30,0x60,0x30,0x60,0x38,0xE0,0x3F,0xE0,0x37,0xE0,0x00,0x60,0x00,0x60,0x00,0x60,0x00,0x60},        // 0xE6
  {0x00,0x00,0x00,0x00,0x03,0xC0,0x03,0xC0,0x01,0x80,0x1F,0x80,0x3F,0x80,0x31,0x80,0x31,0x80,0x3F,0x80,0x1F,0x80,0x01,0x80,0x03,0xC0,0x03,0xC0,0x00,0x00,0x00,0x00},        // 0xE7
  {0x03,0xC0,0x03,0xC0,0x01,0x80,0x1F,0x80,0x3F,0x80,0x31,0x80,0x31,0x80,0x31,0x80,0x31,0x80,0x3F,0x80,0x1F,0x80,0x01,0x80,0x03,0xC0,0x03,0xC0,0x00,0x00,0x00,0x00},        // 0xE8
  {0x18,0x00,0x0C,0x00,0x06,0x00,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x30,0xC0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0xE9
  {0x06,0x00,0x0F,0x00,0x19,0x80,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x30,0xC0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0xEA
  {0x01,0x80,0x03,0x00,0x06,0x00,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x30,0xC0,0x3F,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00},        // 0xEB
  {0x00,0x00,0x00,0x00,0x18,0x00,0x0C,0x00,0x06,0x00,0x30,0xC0,0x30,0xC0,0x19,0x80,0x19,0x80,0x0F,0x00,0x0F,0x00,0x06,0x00,0x06,0x00,0x03,0x00,0x03,0x00,0x01,0x80},        // 0xEC
  {0x18,0x00,0x0C,0x00,0x06,0x00,0x60,0x60,0x30,0xC0,0x19,0x80,0x0F,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x06,0x00,0x00,0x00,0x00,0x00},        // 0xED
  {0x00,0x00,0x00,0x00,0x1E,0x00,0x1E,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xEE
  {0x0C,0x00,0x06,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xEF
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0x80,0x1F,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xF0
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x06,0x00,0x1F,0x80,0x1F,0x80,0x06,0x00,0x06,0x00,0x00,0x00,0x1F,0x80,0x1F,0x80,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xF1
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0x80,0x1F,0x80,0x00,0x00,0x1F,0x80,0x1F,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xF2
  {0x00,0x00,0x00,0x00,0x00,0xE0,0x01,0x80,0x30,0xC0,0x19,0x80,0x0C,0xE0,0x06,0x00,0x6B,0x00,0x6D,0x80,0x7C,0xC0,0x60,0x00,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xF3
  {0x00,0x00,0x7F,0x80,0x36,0xC0,0x36,0x60,0x36,0x60,0x36,0x60,0x36,0xC0,0x37,0x80,0x36,0x00,0x36,0x00,0x36,0x00,0x36,0x00,0x36,0x00,0x36,0x00,0x00,0x00,0x00,0x00},        // 0xF4
  {0x00,0x00,0x1F,0x80,0x30,0xC0,0x00,0xC0,0x00,0xC0,0x1F,0x80,0x30,0xC0,0x30,0xC0,0x1F,0x80,0x30,0x00,0x30,0x00,0x30,0xC0,0x1F,0x80,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xF5
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x06,0x00,0x00,0x00,0x3F,0xC0,0x3F,0xC0,0x00,0x00,0x06,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xF6
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0C,0x80,0x0F,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xF7
  {0x0F,0x00,0x1F,0x80,0x19,0x80,0x19,0x80,0x1F,0x80,0x0F,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xF8
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x80,0x39,0xC0,0x39,0xC0,0x10,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xF9
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x0E,0x00,0x0E,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xFA
  {0x01,0x80,0x01,0xC0,0x01,0x80,0x01,0x80,0x01,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xFB
  {0x03,0xC0,0x06,0x00,0x03,0x80,0x06,0x00,0x03,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xFC
  {0x03,0xC0,0x06,0x00,0x03,0x80,0x00,0xC0,0x07,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xFD
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0x00,0x0F,0x00,0x0F,0x00,0x0F,0x00,0x0F,0x00,0x0F,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},        // 0xFE
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}         // 0xFF
  };
